﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.IO;
using System.Reflection;
using System.Text.RegularExpressions;
using System.Web;
using System.Web.UI;
using SqlUtils;
using System.Configuration;
using WebReports.Api.Common;
using WebReports.Api.Programmability;

namespace ExagoExtensibility
{

    /// <summary>
    /// This class contains methods that will be executed when certain client side moments of the Exago application are reached by a user.
    /// </summary>
    public class ActionEvents
    {
        /** This is a helper method for Action Events so Javascript code can be written in JS files that are stored in the dll as Project Resources.
        * @param resourceName is the name of the project's resource to be loaded (coming from the Scripts folder)
        * @return the content of the resrouce as a string
        */
        internal static string loadJSCode(string resourceName)
        {
            if (!string.IsNullOrEmpty(resourceName))						// can't really do much if there is no file name to work with
            {
                string jsCode = ExagoExtensibility.Properties.Resources.ResourceManager.GetString(resourceName);
                if (!string.IsNullOrEmpty(jsCode))
                    return jsCode;
            }
            return null;
        }

        /** This is a helper method for Action Events so Javascript code can be written in JS files that are stored in the dll as Project Resources.
         * @param sessionInfo this contains all of the active sessions configuration after any API changes have been applied to the base configuration
         * @return the javascriptAction that controls behavior when a user clicks on a report/folder
         */
        public static object onTreeNodeRightClick_SetRightClickMenu(SessionInfo sessionInfo)
        {
                JavascriptAction jsAction = sessionInfo.JavascriptAction;
                // Initialization. Happens when Exago is first loaded in order to set the javascript click event.
                string actionString = loadJSCode("SetNodeRightClickMenu");
                actionString += "SetRightclickMenu();";
                jsAction.SetJsCode(@actionString);
                return sessionInfo.JavascriptAction;
                /*Note: 
                 * Before calling jsAction.SetJsCode you can get values of Parameters from sessionInfo and pass them to the clientside code. 
                 * As an example this could be used to show a custom option in the right click menu that would launch a custom dialog
                 * To accomplish this you'd code as follows
                 *      bool showCustomWindow = Boolean.Parse(sessionInfo.GetParameter("showCustomWindow").Value);
                 *      actionString += string.Format("SetRightclickMenu(\"{0}\");", showCustomWindow);
                */
           
        }
        
    }
}
