﻿using System;
using System.IO;
using System.Text;
using System.Data;
using System.Configuration;
using WebReports.Api;
using System.Net.Mail;
using SqlUtils;
using Newtonsoft.Json;

namespace ExagoExtensibility
{
    /// <summary>
    /// Enumeration to distinguish various types of parties or groups
    /// </summary>
    public enum PartyType : int { Everyone = 0, Class = 1, Company = 2, User = 3};

    /// <summary>
    /// Enumeration to distinguish various types of reports in Exago
    /// </summary>
    public enum ReportType : int { Standard = 0, Express = 1, Dashboard = 2, Chained = 3, Visualization = 4, ExpressView = 5 };

    /// <summary>
    /// Helper class used for the action events that manipulate the Main Menu nodes (ex. folder and reports)
    /// </summary>
    public class NodeData
    {
        public string reportName;
        public string reportId;
        public string reportFullPath;
        public string reportType;
        public string reportUdf;
        public bool isReport;
    }
    
    /// <summary>
    /// Class to hold any custom properties we want to keep with each report and folder
    /// </summary>
    public class UdfProperties
    {

        [JsonProperty(PropertyName = "id")]
        public string Id;
        [JsonProperty(PropertyName = "parentId")]
        public string ParentId;
        [JsonProperty(PropertyName = "sortOrder")]
        public int? SortOrder;
        [JsonProperty(PropertyName = "ownerId")]
        public string OwnerId;
        [JsonProperty(PropertyName = "canRename")]
        public bool CanRename;
        [JsonProperty(PropertyName = "reportType")]
        public int? ReportType;
        [JsonProperty(PropertyName = "partyType")]
        public int? partyType;

        public UdfProperties(string id, string parentId, int? sortOrder, string ownerId, bool canRename,  int? reportType, int? partyType)
        {
            this.Id = id;
            this.ParentId = parentId;
            this.SortOrder = sortOrder;
            this.OwnerId = ownerId;
            this.CanRename = canRename;
            this.ReportType = reportType;
            this.partyType = partyType;
        }

        public override string ToString()
        {
            return JsonConvert.SerializeObject(this);
        }
    }

    /// <summary>
    /// Class that reads specific database table name appSettings configurations from the executing
    /// program's web.config and caches them in memory for fast reference.
    /// </summary>
    public static class DbTables
    {
        public static string Reports { get; set; }
        public static string ReportAccess { get; set; }
        public static string UserPreferences { get; set; }

        static DbTables()
        {

            Reports = ConfigurationManager.AppSettings["tnReports"];
            ReportAccess = ConfigurationManager.AppSettings["tnReportAccess"];
            UserPreferences = ConfigurationManager.AppSettings["tnUserPreferences"];
           
        }
    }

    /// <summary>
    /// This static class contains a number of unrelated methods that are used in various disjoint places in the system.
    /// </summary>
    public static class Utilities
	{
		private static DbObjectFactory.DataSourceType db = DbObjectFactory.GetDataSourceType(ConfigurationManager.ConnectionStrings["DefaultConnection"].ProviderName);
		private static string connectionString = ConfigurationManager.ConnectionStrings["DefaultConnection"].ConnectionString;


        /// <summary>
        /// Read a file to string, line by line, and return the string.
        /// </summary>
        /// <param name="fileName">The file to read.</param>
        /// <returns>Returns the file contents as a string.</returns>
        public static string readFileToString(string fileName)
		{
			string str;
			StringBuilder sb = new StringBuilder(); // string builders can be easily changed, whereas strings are immutable and inefficient when concatenating
			try
			{
				using (StreamReader sr = File.OpenText(fileName))
				{
					str = sr.ReadLine(); // read first line
					while (str != null)  // if we're not at the end of the file, keep going
					{
						sb.Append(str + System.Environment.NewLine); // concatenate new line to existing string buffer; tack on a environment-specific carriage return
						str = sr.ReadLine(); // read next line
					}
				}
			}
			catch (Exception ex)
			{
				sb.Append("Could not read the source code file because: ");
				sb.Append(ex.Message);
			}
			return sb.ToString();
		}
	}
}

