﻿function SetRightclickMenu() {
	clientInfo.refreshDataOnReturn = false;
    var node = clientInfo.utilities.TreeCtrl.GetSelectedNode(clientInfo.webReportsCtrl.reportsTreeId);
    if (node !== null)		                                       // The user may have right-clicked on a non-node before a node was selected
    {
        // Determine if the node is a report or a folder
        var isReport = !clientInfo.webReportsCtrl.ReportFoldersCtrl.IsFolder(node);
        
        // Get the ID of the node
        var menuId = (isReport ? clientInfo.webReportsCtrl.reportContextMenuId : clientInfo.webReportsCtrl.folderContextMenuId);
        
        //Verify the node has a UDF (it might not if it is a newly created folder)
        if(node.getAttribute("data-udf"))
        {
            // Check the Udf to see if the user has permission to rename or delete the node. 
            var reportUdfObj = JSON.parse(node.getAttribute("data-udf"));
            //If not disable those options (and disable moving folders to root)
            if (!reportUdfObj.canRename)
            {
                if (!isReport) {
                    clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "rename", false);
                    clientInfo.utilities.PopupMenuCtrl.SetItemTooltipText(menuId, "rename", clientInfo.GetLanguageData("CannotRenameFolder", false).Html);
                    clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "delete", false);
                    clientInfo.utilities.PopupMenuCtrl.SetItemTooltipText(menuId, "delete", clientInfo.GetLanguageData("CannotDeleteFolder", false).Html);
                    clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "movetoroot", false);
                    clientInfo.utilities.PopupMenuCtrl.SetItemTooltipText(menuId, "movetoroot", clientInfo.GetLanguageData("CannotMoveFolder", false).Html);
                }
                else
                {
                    clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "rename", false);
                    clientInfo.utilities.PopupMenuCtrl.SetItemTooltipText(menuId, "rename", clientInfo.GetLanguageData("CannotRenameReport", false).Html);
                    clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "delete", false);
                    clientInfo.utilities.PopupMenuCtrl.SetItemTooltipText(menuId, "delete", clientInfo.GetLanguageData("CannotDeleteReport", false).Html);
                }
                /*Note: 
                 * You could add here additional clickable items if you wanted to say give an option to launch a custom dialog   
                 * To accomplish this you'd code as follows
                        if(showCustomDialog)
                        {
                            clientInfo.utilities.PopupMenuCtrl.AddSeparator(menuId, "showCustomDialog");
                            clientInfo.utilities.PopupMenuCtrl.AddItem(menuId, clientInfo.GetLanguageData("ReportTreeContextMenuCustomDialog", false).Html, "custom", "Images/CustomDialog.png");
                        }
                */
            }
        }
            
        //Set the behavior when a user clicks each item the right click menu
        //The onclick menthod first creates json containing the node's name, full path and bool if it is a report/folder. Then make a serverside callback to get the report's ID and publsihed status
        clientInfo.utilities.PopupMenuCtrl.SetOnClick(menuId,
                    function (key) {
                        var reportName = clientInfo.utilities.GetText(node);
                        var reportTypeEnum = node.getAttribute("data-reporttype");
                        var reportUdf = node.getAttribute("data-udf");
                        var reportFullPath = clientInfo.utilities.TreeCtrl.GetFullSelectedNodeText(clientInfo.webReportsCtrl.reportsTreeId);
                        var nodeData = { reportName: reportName, reportType: reportTypeEnum, reportFullPath: reportFullPath, isReport: isReport, reportUdf: reportUdf};
                        isReport ? clientInfo.webReportsCtrl.ReportTreeReportMenu_ItemClick(key) : clientInfo.webReportsCtrl.ReportTreeFolderMenu_ItemClick(key);
                        /*Note:
                        * If adding a custom item you would use a switch statement to set the onclick property of your custom option
                        * To accomplish this you'd code as follows  
                            switch (key) 
                            {
                                case "custom":
                                    clientInfo.ServerCallback("custom_OpenCustomDialog", nodeData);
                                    break;
                                default:                                             // handle default popup menu items 
                                    isReport ? clientInfo.webReportsCtrl.ReportTreeReportMenu_ItemClick(key) : clientInfo.webReportsCtrl.ReportTreeFolderMenu_ItemClick(key);                                
                            } 
                        */
                    }
                    );
        clientInfo.utilities.PopupMenuCtrl.SetOnClose(menuId,
                      function (key){
                          // Remove  the share option when the menu is closed so it doesn't get added multiple times.
                          if (node.getAttribute("data-udf")) {
                              // Check the Udf to see if the user has permission to rename or delete the report. If not remove those options (and disable moving folders to root)
                              var reportUdfObj = JSON.parse(node.getAttribute("data-udf"));
                              if (!reportUdfObj.canRename)
                              {
                                  clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "rename", true);
                                  clientInfo.utilities.PopupMenuCtrl.ClearItemTooltipText(menuId, "rename");
                                  clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "delete", true);
                                  clientInfo.utilities.PopupMenuCtrl.ClearItemTooltipText(menuId, "delete");
                                  if (!isReport) {
                                      clientInfo.utilities.PopupMenuCtrl.EnableItem(menuId, "movetoroot", true);
                                      clientInfo.utilities.PopupMenuCtrl.ClearItemTooltipText(menuId, "movetoroot");
                                  }
                              }
                              /*Note:
                              * If adding a custom item you would remove the item when the menu closes to prevent it appearing in duplicate thenext time a node is clicked
                              * To accomplish this you'd code as follows 
                                    if (showCustomDialog) {
                                        clientInfo.utilities.PopupMenuCtrl.RemoveItem(menuId, "custom");
                                    }
                              */
                          }
                      });


    }
}