﻿using System;
using System.Data;
using SqlUtils;
using System.Configuration;
using WebReports.Api.Common;

namespace ExagoExtensibility
{
    /// <summary>
    /// This class contains methods that will be executed when certain server side moments of the Exago application are reached by a user.
    /// </summary>
    public class ServerEvents
    {

        //		private static DbObjectFactory.DataSourceType db = DbObjectFactory.DataSourceType.SqlServer;
        private static DbObjectFactory.DataSourceType db = DbObjectFactory.GetDataSourceType(ConfigurationManager.ConnectionStrings["DefaultConnection"].ProviderName);
        private static string connectionString = ConfigurationManager.ConnectionStrings["DefaultConnection"].ConnectionString;

		/**
		 * Triggered by the OnGetUserPreference Server Event, in conjunction with the User Preference Storage 
		 * Method (set to Server Event) in User Settings, this hook implementation retrieves the user preference
		 * from a database table.
		 * @param sessionInfo is the SessionInfo object as provided by Exago
		 * @param id is the user preference id
		 * @return the user preference identified by the given user preference id and user
		 */ 
		public static string getUserPreference(SessionInfo sessionInfo, string id)
		{
			string retVal = null;
			try
			{
				DbSqlHandler sql = new DbSqlHandler(db, connectionString);
				sql.Stmt = string.Format("SELECT upValue FROM {0} WHERE upId = @id AND userId=@userId; ", DbTables.UserPreferences);
				sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@id", id, DbType.String));
				sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@userId", sessionInfo.UserId, DbType.String));
				retVal = (string)sql.ExecuteScalarCmd();
			} catch 
			{
				// log any error here using your perfered logging
			}

			return retVal;
		}

		/**
		 * Triggered by the OnSetUserPreference Server Event, in conjunction with the User Preference Storage 
		 * Method (set to Server Event) in User Settings, this hook implementation sets the user preference
		 * in a database table.
		 * @param sessionInfo is the SessionInfo object as provided by Exago
		 * @param id is the user preference id
		 * @param value is the user preference value
		 */
		public static void setUserPreference(SessionInfo sessionInfo, string id, string value)
		{
			object objVal = DBNull.Value;
			if (!string.IsNullOrEmpty(value))
				objVal = value;

			try
			{
				DbSqlHandler sql = new DbSqlHandler(db, connectionString);
                //Call getUserPrefence to see if we need to update an existing preference or insert a new db row
				if (string.IsNullOrEmpty(ServerEvents.getUserPreference(sessionInfo, id)))
				{
                    //if no u.p. already exists insert a row into the database
					sql.Stmt = string.Format("INSERT INTO {0} (userId, upId, upValue) VALUES (@userId, @id, @upValue)", DbTables.UserPreferences);
					sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@userId", sessionInfo.UserId, DbType.String));
					sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@id", id, DbType.String));
					sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@upValue", value, DbType.String));

					sql.ExecuteNQCmd();
				}
				else
				{
                    //otherwise updated the database row
					sql.Stmt = string.Format("UPDATE {0} SET upValue=@upValue WHERE userId=@userId AND upId=@id", DbTables.UserPreferences);
					sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@userId", sessionInfo.UserId, DbType.String));
					sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@id", id, DbType.String));
					sql.SqlParams.Add(DbObjectFactory.GetParameter(db, "@upValue", value, DbType.String));
					sql.ExecuteNQCmd();
				}
			}
			catch 
			{
                // log any error here using your perfered logging
            }
        }
	}
}
